---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: Cryotap

---

**Describe the feature you'd like**
A clear and concise description of what you want and how it should work.

**Additional context**
Add any other context or screenshots about the feature request here.
